@@ -8,11 +8,10 @@ use Net::EPP::Frame::Response;
 use POSIX qw(strftime);
 use XML::LibXML;
 use base qw(XML::LibXML::Document);
-use vars qw($EPP_URN $SCHEMA_URI);
+use vars qw($EPP_URN);
 use strict;
 
-our $EPP_URN	= 'urn:ietf:params:xml:ns:epp-1.0';
-our $SCHEMA_URI	= 'http://www.w3.org/2001/XMLSchema-instance';
+our $EPP_URN = 'urn:ietf:params:xml:ns:epp-1.0';
 
 =pod
 
@@ -105,18 +104,14 @@ Net::EPP::Frame - An EPP XML frame system built on top of L<XML::LibXML>.
 
 =head1 DESCRIPTION
 
-EPP is the Extensible Provisioning Protocol. EPP (defined in RFC 4930) is an
-application layer client-server protocol for the provisioning and management of
-objects stored in a shared central repository. Specified in XML, the protocol
-defines generic object management operations and an extensible framework that
-maps protocol operations to objects. As of writing, its only well-developed
-application is the provisioning of Internet domain names, hosts, and related
-contact details.
+The L<Extensible Provisioning Protocol
+(EPP)|https://www.rfc-editor.org/info/std69> uses XML documents called "frames"
+send data to and from clients and servers.
 
-EPP uses XML documents called "frames" send data to and from clients
-and servers. This module implements a subclass of the L<XML::LibXML::Document>
-module that simplifies the process of creation of these frames. It is designed
-to be used alongside the L<Net::EPP::Client> module.
+This module implements a subclass of the L<XML::LibXML::Document> module that
+simplifies the process of creation of these frames. It is designed to be used
+alongside the L<Net::EPP::Client> and L<Net::EPP::Simple> modules, but could
+also be used on the server side.
 
 =head1 OBJECT HIERARCHY
 
@@ -124,18 +119,17 @@ to be used alongside the L<Net::EPP::Client> module.
     +----L<XML::LibXML::Document>
         +----L<Net::EPP::Frame>
 
-
 =head1 USAGE
 
-As a rule, you will not need to create Net::EPP::Frame objects directly.
+As a rule, you will not need to create C<Net::EPP::Frame> objects directly.
 Instead, you should use one of the subclasses included with the distribution.
-The subclasses all inherit from Net::EPP::Frame.
+The subclasses all inherit from C<Net::EPP::Frame>.
 
-Net::EPP::Frame is itself a subclass of L<XML::LibXML::Document> so all the
+C<Net::EPP::Frame> is itself a subclass of L<XML::LibXML::Document> so all the
 methods available from that class are also available to instances of
-Net::EPP::Frame.
+C<Net::EPP::Frame>.
 
-The available subclasses of Net::EPP::Frame exist to add any additional
+The available subclasses of C<Net::EPP::Frame> exist to add any additional
 elements required by the EPP specification. For example, the E<lt>loginE<gt>
 frame must contain the E<lt>clIDE<gt> and E<lt>pwE<gt> frames, so when you
 create a new L<Net::EPP::Frame::Command::Login> object, you get these already
@@ -156,30 +150,30 @@ has to be a win.
 =cut
 
 sub new {
-	my ($package, $type) = @_;
+    my ($package, $type) = @_;
 
-	if (!$type) {
-		my @parts = split(/::/, $package);
-		$type = lc(pop(@parts));
-	}
+    if (!$type) {
+        my @parts = split(/::/, $package);
+        $type = lc(pop(@parts));
+    }
 
-	if ($type !~ /^(hello|greeting|command|response)$/) {
-		croak("'type' parameter to Net::EPP::Frame::new() must be one of: hello, greeting, command, response ('$type' given).");
-		return undef;
-	}
+    if ($type !~ /^(hello|greeting|command|response)$/) {
+        croak("'type' parameter to Net::EPP::Frame::new() must be one of: hello, greeting, command, response ('$type' given).");
+        return undef;
+    }
 
-	my $self = $package->SUPER::new('1.0', 'UTF-8');
-	bless($self, $package);
+    my $self = $package->SUPER::new('1.0', 'UTF-8');
+    bless($self, $package);
 
-	my $epp = $self->createElementNS($EPP_URN, 'epp');
-	$self->addChild($epp);
+    my $epp = $self->createElementNS($EPP_URN, 'epp');
+    $self->addChild($epp);
 
-	my $el = $self->createElement($type);
-	$epp->addChild($el);
+    my $el = $self->createElement($type);
+    $epp->addChild($el);
 
-	$self->_addExtraElements;
+    $self->_addExtraElements;
 
-	return $self;
+    return $self;
 }
 
 sub _addExtraElements {
@@ -197,8 +191,8 @@ is a convenience method.
 =cut
 
 sub formatTimeStamp {
-	my ($self, $stamp) = @_;
-	return strftime('%Y-%m-%dT%H:%M:%S.0Z', gmtime($stamp));
+    my ($self, $stamp) = @_;
+    return strftime('%Y-%m-%dT%H:%M:%S.0Z', gmtime($stamp));
 }
 
 =pod
@@ -215,17 +209,17 @@ If C<$ns> is provided, then I<getElementsByTagNameNS()> is used.
 =cut
 
 sub getNode {
-	my ($self, @args) = @_;
-	if (scalar(@args) == 2) {
-		return ($self->getElementsByTagNameNS(@args))[0];
+    my ($self, @args) = @_;
+    if (scalar(@args) == 2) {
+        return ($self->getElementsByTagNameNS(@args))[0];
 
-	} elsif (scalar(@args) == 1) {
-		return ($self->getElementsByTagName($args[0]))[0];
+    } elsif (scalar(@args) == 1) {
+        return ($self->getElementsByTagName($args[0]))[0];
 
-	} else {
-		croak('Invalid number of arguments to getNode()');
+    } else {
+        croak('Invalid number of arguments to getNode()');
 
-	}
+    }
 }
 
 =pod
@@ -238,8 +232,8 @@ only useful for low-level protocol stuff.
 =cut
 
 sub header {
-	my $self = shift;
-	return pack('N', length($self->toString) + 4);
+    my $self = shift;
+    return pack('N', length($self->toString) + 4);
 }
 
 =pod
@@ -253,8 +247,8 @@ low-level protocol stuff.
 =cut
 
 sub frame {
-	my $self = shift;
-	return $self->header.$self->toString;
+    my $self = shift;
+    return $self->header . $self->toString;
 }
 
 =pod
@@ -263,42 +257,48 @@ sub frame {
 
 =over
 
-=item L<Net::EPP::Frame>, the base class
+=item * L<Net::EPP::Frame>, the base class
 
-=item L<Net::EPP::Frame::Command>, for EPP client command frames
+=item * L<Net::EPP::Frame::Command>, for EPP client command frames
 
-=item L<Net::EPP::Frame::Command::Check>, for EPP E<lt>checkE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Check>, for EPP E<lt>checkE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Create>, for EPP E<lt>createE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Create>, for EPP E<lt>createE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Delete>, for EPP E<lt>deleteE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Delete>, for EPP E<lt>deleteE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Info>, for EPP E<lt>infoE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Info>, for EPP E<lt>infoE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Login>, for EPP E<lt>loginE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Login>, for EPP E<lt>loginE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Logout>, for EPP E<lt>logoutE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Logout>, for EPP E<lt>logoutE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Poll>, for EPP E<lt>pollE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Poll>, for EPP E<lt>pollE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Renew>, for EPP E<lt>renewE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Renew>, for EPP E<lt>renewE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Transfer>, for EPP E<lt>transferE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Transfer>, for EPP E<lt>transferE<gt> client commands
 
-=item L<Net::EPP::Frame::Command::Update>, for E<lt>updateE<gt> client commands
+=item * L<Net::EPP::Frame::Command::Update>, for E<lt>updateE<gt> client commands
 
-=item L<Net::EPP::Frame::Greeting>, for EPP server greetings
+=item * L<Net::EPP::Frame::Greeting>, for EPP server greetings
 
-=item L<Net::EPP::Frame::Hello>, for EPP client greetings
+=item * L<Net::EPP::Frame::Hello>, for EPP client greetings
 
-=item L<Net::EPP::Frame::Response>, for EPP server response frames
+=item * L<Net::EPP::Frame::Response>, for EPP server response frames
 
 =back
 
-Each subclass has its own subclasses for various objects, for example L<Net::EPP::Frame::Command::Check::Domain> creates C<E<lt>checkE<gt>> frame for domain names.
+Each subclass has its own subclasses for various objects, for example L<Net::EPP::Frame::Command::Check::Domain> creates a C<E<lt>checkE<gt>> frame for domain names.
 
 Coverage for all combinations of command and object type is not complete, but work is ongoing.
 
+=head1 COPYRIGHT
+
+This module is (c) 2008 - 2023 CentralNic Ltd and 2024 Gavin Brown. This module
+is free software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
+
 =cut
 
 1;
